==> openerp-7.0.2311.1.tar.gz: openerp-7.0.2311.1/openerp/addons/healthcheck/__openerp__.py <==
# -*- coding: utf-8 -*-

##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{
  'name': 'Healthcheck',
  'category': 'Monitoring',
  'author': 'Infra7 Serviços em TI',
  'version': '7.0.2311.1',
  'summary': 'Healthcheck periodically checks if server and database are alive',
  'description': """
Server health agent module
==========================

This module monitors the status of the OpenERP HTTP and Cron processes.
It depends on the client script that query the endpoint routine on server
via Web service.
""",
  'depends': ['base','web'],
  'images': ['static/images/healthcheck.png'],
  'installable': True,
  'auto_install': True,
}

==> openerp-7.0.2401.1.tar.gz: openerp-7.0.2401.1/openerp/addons/healthcheck/__openerp__.py <==
# -*- coding: utf-8 -*-

##############################################################################
#
#    Odoo, Open Source Management Solution
#    Copyright (C) 2023-2024
#      Infra7 Serviços em TI (<https://github.com/infra7ti>)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{
  'name': 'Healthcheck',
  'category': 'Monitoring',
  'author': 'Infra7 Serviços em TI',
  'version': '7.0.2401.1',
  'summary': 'Healthcheck periodically checks if server and database are alive',
  'description': """
Server health agent module
==========================

This module monitors the status of the OpenERP HTTP and Cron processes.
It depends on the client script that query the endpoint routine on server
via Web service.
""",
  'depends': ['base','web'],
  'images': ['/healthcheck/static/images/healthcheck.png'],
  'installable': True,
  'auto_install': True,
}
